@@ -1,12 +1,10 @@
 package Cassandra::Client::Policy::Auth::Password;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Policy::Auth::Password::VERSION = '0.17';
+$Cassandra::Client::Policy::Auth::Password::VERSION = '0.18';
 use 5.010;
 use strict;
 use warnings;
 
-use Cassandra::Client::Protocol qw/pack_bytes/;
-
 sub new {
     my ($class, %args)= @_;
 
@@ -30,7 +28,7 @@ sub evaluate {
     my $pass= $self->{password};
     utf8::encode($user) if utf8::is_utf8($user);
     utf8::encode($pass) if utf8::is_utf8($pass);
-    return $callback->(undef, pack_bytes("\0$user\0$pass"));
+    return $callback->(undef, "\0$user\0$pass");
 }
 
 sub success {
@@ -50,7 +48,7 @@ Cassandra::Client::Policy::Auth::Password
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 AUTHOR
 
